pub struct ModuleDirectory { /* private fields */ }Available on crate feature
fs only.Expand description
A module directory stored on a file system (e.g., $HOME/.asimov/modules/).
Implementations
Sourceimpl ModuleDirectory
impl ModuleDirectory
Sourcepub fn home() -> Result<Self>
pub fn home() -> Result<Self>
Opens the default module directory in the user’s home directory.
On Unix platforms, including macOS and Linux, this is $HOME/.asimov/modules/.
Sourcepub fn open(path: impl AsRef<Path>) -> Result<Self>
pub fn open(path: impl AsRef<Path>) -> Result<Self>
Opens a module directory from a file system path.
pub async fn iter_enabled(&self) -> Result<ModuleNameIterator>
pub async fn iter_installed(&self) -> Result<ModuleNameIterator>
pub async fn iter_manifests(&self) -> Result<ModuleManifestIterator>
pub fn join(&self, path: impl AsRef<Utf8Path>) -> Utf8PathBuf
pub fn as_str(&self) -> &str