pub struct ProgramDirectory { /* private fields */ }Available on crate feature
fs only.Expand description
A program directory stored on a file system (e.g., $HOME/.asimov/libexec/).
Implementations
Sourceimpl ProgramDirectory
impl ProgramDirectory
Sourcepub fn home() -> Result<Self>
pub fn home() -> Result<Self>
Opens the default program directory in the user’s home directory.
On Unix platforms, including macOS and Linux, this is $HOME/.asimov/libexec/.
Sourcepub fn open(path: impl AsRef<Path>) -> Result<Self>
pub fn open(path: impl AsRef<Path>) -> Result<Self>
Opens a program directory from a file system path.
pub fn join(&self, path: impl AsRef<Utf8Path>) -> Utf8PathBuf
pub fn as_str(&self) -> &str